Oineus
==========

Oineus is a computational topology library that contains:

* Shared-memory parallel algorithm to compute persistent homology.
* Critical set method for topological optimization.
* Zero-persistence diagrams.
* Persistence kernel-image-cokernel computaton.

Documentation
-------------

See docs/tutorial.md.
